#[repr(i32)]pub enum SlotConfidence {
ConfidenceLow = 0,
ConfidenceMid = 1,
ConfidenceHigh = 2,
}Expand description
SlotConfidence indicates how confident the device is in its classification of a peeked slot, based on content, filename, and size.
Variants
ConfidenceLow = 0
Filename/extension only, no content confirmation
ConfidenceMid = 1
Format detected but slot type inferred from size/filename
ConfidenceHigh = 2
Magic bytes match and format-specific content confirmed
Implementations
Sourceimpl SlotConfidence
impl SlotConfidence
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.