#[repr(i32)]pub enum SlotKind {
SlotReferenceGenome = 0,
SlotGeneAnnotations = 1,
SlotSnpIndelCalls = 2,
SlotVariantCatalog = 3,
}Expand description
SlotKind identifies a slot slot on the device. Each value corresponds to a unique data type that the device can store and manage.
Variants
SlotReferenceGenome = 0
Human reference genome assembly
SlotGeneAnnotations = 1
Gene-to-coordinate mapping database
SlotSnpIndelCalls = 2
User’s SNP/indel variant calls
SlotVariantCatalog = 3
Variant catalog (rsID-to-position), from dbSNP
Implementations
Sourceimpl SlotKind
impl SlotKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.