connect

Function connect 

pub fn connect<R, W, V>(
    stream: Stream<R, W>,
    verifier: &V,
) -> Result<(Session, V::Info), Error>
where R: Read + Send + 'static, W: Write + Send + 'static, V: Verifier,
Establishes a client session, verifies the peer and returns the verifier’s info. Takes ownership of the stream and constructs the transport internally. Failure closes the client stream; the application can open another stream and reconnect. The verifier is only borrowed during this blocking call. Failure to start a required worker or an escaping worker panic aborts the process.