Content

Enum Content 

pub enum Content {
Show 35 variants Onboard(OnboardingRequest), DeviceInfo(DeviceInfoRequest), CloudSyncStart(CloudSyncStartRequest), CloudSyncFinish(CloudSyncFinishRequest), GenuinityProof(GenuinityProofRequest), FirmwareUpdatePrep(FirmwareUpdatePrepRequest), FirmwareUpdateInit(FirmwareUpdateInitRequest), FirmwareUpdateUpload(FirmwareUpdateUploadRequest), FirmwareUpdateVerify(FirmwareUpdateVerifyRequest), FirmwareUpdateInstall(FirmwareUpdateInstallRequest), PairingStatus(PairingStatusRequest), PairingAuth(PairingAuthRequest), PairingSetAppId(PairingSetAppIdentityRequest), PairingSetAppStorage(PairingSetAppStorageRequest), PairingAckArkStorage(PairingAckArkStorageRequest), PairingAccept(PairingAcceptanceRequest), PairingComplete(PairingCompletionRequest), RelayJoin(RelayJoinRequest), RelayReq(RelayAppToArkRequest), RelayRes(RelayAppToArkResponse), Unlock(UnlockRequest), ExecUploadStart(ExecutionUploadStartRequest), ExecUploadChunk(ExecutionUploadChunkRequest), ExecSched(ExecutionScheduleRequest), ExecStatus(ExecutionStatusRequest), ExecCancel(ExecutionCancelRequest), SlotList(SlotListRequest), SlotRepair(SlotRepairRequest), SlotDelete(SlotDeleteRequest), SlotUploadPeek(SlotUploadPeekRequest), SlotUploadStart(SlotUploadStartRequest), SlotUploadChunk(SlotUploadChunkRequest), SlotUploadCancel(SlotUploadCancelRequest), SlotUploadProcess(SlotUploadProcessRequest), Develop(Vec<u8>),
}

Variants



Onboard(OnboardingRequest)

Special factory message



DeviceInfo(DeviceInfoRequest)

System messages, reserved range 0x101-0x200



CloudSyncStart(CloudSyncStartRequest)



CloudSyncFinish(CloudSyncFinishRequest)



GenuinityProof(GenuinityProofRequest)



FirmwareUpdatePrep(FirmwareUpdatePrepRequest)

Firmware update messages, reserved range 0x201-0x300



FirmwareUpdateInit(FirmwareUpdateInitRequest)



FirmwareUpdateUpload(FirmwareUpdateUploadRequest)



FirmwareUpdateVerify(FirmwareUpdateVerifyRequest)



FirmwareUpdateInstall(FirmwareUpdateInstallRequest)



PairingStatus(PairingStatusRequest)

Pairing messages, reserved range 0x301-0x400



PairingAuth(PairingAuthRequest)



PairingSetAppId(PairingSetAppIdentityRequest)



PairingSetAppStorage(PairingSetAppStorageRequest)



PairingAckArkStorage(PairingAckArkStorageRequest)



PairingAccept(PairingAcceptanceRequest)



PairingComplete(PairingCompletionRequest)



RelayJoin(RelayJoinRequest)

Relay messages, reserved range 0x401-0x500



RelayReq(RelayAppToArkRequest)



RelayRes(RelayAppToArkResponse)



Unlock(UnlockRequest)

Operational messages, reserved range 0x501-0x600



ExecUploadStart(ExecutionUploadStartRequest)



ExecUploadChunk(ExecutionUploadChunkRequest)



ExecSched(ExecutionScheduleRequest)



ExecStatus(ExecutionStatusRequest)



ExecCancel(ExecutionCancelRequest)



SlotList(SlotListRequest)

Slot messages, reserved range 0x601-0x700



SlotRepair(SlotRepairRequest)



SlotDelete(SlotDeleteRequest)



SlotUploadPeek(SlotUploadPeekRequest)



SlotUploadStart(SlotUploadStartRequest)



SlotUploadChunk(SlotUploadChunkRequest)



SlotUploadCancel(SlotUploadCancelRequest)



SlotUploadProcess(SlotUploadProcessRequest)



Develop(Vec<u8>)

Unreleased messages served by development firmware only, carried opaquely so the public protocol is untouched while they are still under development. Their schema is private and production Arks refuse the envelope.

Implementations

Source

impl Content

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<Content>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.