pub struct CloudSyncFinishRequest {
pub unixmilli: u64,
pub signature: Vec<u8>,
}Expand description
CloudSyncFinishRequest is the completion of a previously initiated cloud sync procedure, this time being signed by a single identity currently used by the cloud.
Fields
unixmilli: u64Unix timestamp from the server in milliseconds
signature: Vec<u8>SignAt[Cloud][“cloudsync-v1”]unixmilli/1000