pub struct CloudSyncFinishResponse {
pub accepted: u64,
}Expand description
CloudSyncFinishResponse is the acknowledgement whether the device accepted the cloud sync from the server or rejected for some reason.
Fields
accepted: u64Timestamp that was accepted and set