pub struct CloudSyncStartRequest {
pub signer: Vec<u8>,
pub crypto: Vec<u8>,
}Expand description
CloudSyncStartRequest requests the device to start a synchronization procedure against the cloud servers to establish the current time as well as the currently active cloud identity.
Fields
signer: Vec<u8>Post-quantum CWT attestation for the server signing (xDSA) key
crypto: Vec<u8>Post-quantum CWT attestation for the server encryption (xHPKE) key