pub struct ExecutionScheduleResponse {}Expand description
ExecutionScheduleResponse acks that the execution was authorized and the task is now running. The host already holds the task id from the preceding ExecutionUploadStartResponse.