pub struct FirmwareUpdateInitResponse {}Expand description
FirmwareUpdateInitResponse confirms whether a new firmware update process was started, or if the request was rejected and why.
Note, if the init is rejected, the entire update process is torn down.