pub struct FirmwareUpdateVerifyResponse {}Expand description
FirmwareUpdateVerifyResponse is the response whether the firmware just uploaded passed all verifications and is ready for application.
Note, if the verification is rejected, the entire update process is torn down.