OnboardingRequest

Struct OnboardingRequest 

pub struct OnboardingRequest {
    pub device_attestation: Vec<u8>,
}
OnboardingRequest is a vendor utility to onboard an Ark. Currently it contains the signed device genuinity attestation (certificate).

Note, as this method is only used during initial device setup, there is no API compatibility guarantee, it will evolve with the factory tooling.

Fields

device_attestation: Vec<u8>

Signed device genuinity attestation (CWT) to install