pub struct PairingAcceptanceResponse {
pub confirm: Vec<u8>,
}Expand description
PairingAcceptanceResponse returns whether the user accepted the pairing or if it timed out. At this point, the device still needs to format itself.
Fields
confirm: Vec<u8>Seal[Ark->Cloud][“pairing-v1:accept”][ark_signer_id, ark_crypto_id, app_signer_id, app_crypto_id]