pub struct PairingSetAppStorageResponse {
pub ark_keys: Vec<u8>,
}Expand description
PairingSetAppStorageResponse confirms whether the remote storage material was accepted, and if so, bundles the ark device infos and ark key material.
Fields
ark_keys: Vec<u8>Seal[Ark->App][“pairing-v1:storage”][[ark_signer_id, ark_crypto_id, app_signer_id, app_crypto_id, app_keymat]]([hw_ver, hw_rev, fw_ver, fw_pub, ark_keymat])