pub struct RelayAppToArkFailure {
pub error: String,
}Expand description
RelayAppToArkFailure is returned if a low level protocol violation is detected when an app-to-ark response was processed.
This is not an actionable message, rather it’s just a way to expose a protocol failure / violation to the calling app for debugging purposes.
Fields
error: StringReason for rejecting the response at the protocol level