pub struct RelayAppToArkRequest {
pub id: u64,
pub req: Vec<u8>,
}Expand description
RelayAppToArkRequest is an opaque request from the companion app that the Ark may respond to, or may flat out reject.
Fields
id: u64Application layer request ID from the app
req: Vec<u8>Seal[App->Ark][“relaying-v1:request”][id]([method, [params…]]))