pub struct SlotIdentifyRequest {
pub name: String,
pub size: u64,
pub chunk: Vec<u8>,
pub kinds: Vec<i32>,
}Expand description
SlotIdentifyRequest sends an ephemeral file chunk to the Ark and asks it to identify the file. Its purpose is to filter potentially huge files (e.g. a 30GB compressed whole genome sequencing) before uploading them, and to answer what a file is without uploading it at all.
Fields
name: StringFile name to guess the contents of
size: u64File size to guess the contents of
chunk: Vec<u8>First chunk of the file to guess the contents of
kinds: Vec<i32>Possible slots to interpret as (empty == any)
Implementations