pub struct SlotIdentifyResponse {
pub kind: i32,
pub conf: i32,
pub summary: String,
pub details: String,
pub rejection: String,
}Expand description
SlotIdentifyResponse contains the identification based on the chunk shared in the request.
Fields
kind: i32Identified slot type to use during upload
conf: i32Identification confidence level
summary: StringShort summary of the identified data
details: StringDetailed description of the identified data
rejection: StringReason why the file is rejected, empty otherwise
Implementations
Sourceimpl SlotIdentifyResponse
impl SlotIdentifyResponse
Sourcepub fn kind(&self) -> SlotKind
pub fn kind(&self) -> SlotKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn conf(&self) -> SlotConfidence
pub fn conf(&self) -> SlotConfidence
Returns the enum value of conf, or the default if the field is set to an invalid enum value.
Sourcepub fn set_conf(&mut self, value: SlotConfidence)
pub fn set_conf(&mut self, value: SlotConfidence)
Sets conf to the provided enum value.