pub struct SlotUploadStartRequest {
pub kind: i32,
pub name: String,
pub size: u64,
pub chunk: Vec<u8>,
}Expand description
SlotUploadStartRequest requests uploading a specific type of slot (e.g a whole genome variant call file, a bloodwork report).
Fields
kind: i32Slot type requesting to upload
name: StringSlot file name to guess the contents of
size: u64Slot file size to guess the contents of
chunk: Vec<u8>Slot first chunk to guess the contents of
Implementations