pub enum Meta {
ReferenceGenome(SlotMetaReferenceGenome),
GeneAnnotations(SlotMetaGeneAnnotations),
SnpIndelCalls(SlotMetaSnpIndelCalls),
VariantCatalog(SlotMetaVariantCatalog),
}Expand description
Slot-type-specific metadata, set when the device has information about this slot (either filled or dependencies provide enough context).
Variants
ReferenceGenome(SlotMetaReferenceGenome)
GeneAnnotations(SlotMetaGeneAnnotations)
SnpIndelCalls(SlotMetaSnpIndelCalls)
VariantCatalog(SlotMetaVariantCatalog)
Implementations
Sourceimpl Meta
impl Meta
Sourcepub fn merge(
field: &mut Option<Meta>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Meta>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.