pub struct ArkToHost {
pub id: Option<u64>,
pub err: Option<Error>,
pub content: Option<Content>,
}Expand description
ArkToHost represents a message sent from the Ark to the host via the USB connection. It embeds all possible message types to keep the protocol simple.
Fields
id: Option<u64>Response enveloping fields, reserved range 0x001-0xff
Request identifier responding to (if any)
err: Option<Error>Error encountered while serving (if any)
content: Option<Content>Implementations