pub struct CloudSyncStartResponse {
pub challenge: Vec<u8>,
}Expand description
CloudSyncStartResponse is an initiation of a cloud sync from the device, authed to the requested cloud identity.
Fields
challenge: Vec<u8>Random nonce to avoid malicious host machines setting bad times