pub struct ExecutionScheduleRequest {
pub taskid: u64,
}Expand description
ExecutionScheduleRequest finalizes an upload and requests the device to execute the uploaded 3rd party app. The upload must have been completed (i.e. the sum of chunk sizes matches the declared size).
This request is async, potentially returning a response only after confirming with the app.
It will trigger sending a RelayArkToAppRequest with the request content:
- method: “execute”
- params: [task: string]
The request expects a RelayAppToArkResponse with the response content:
If approved: - result = approval = true // CBOR boolean - err_code: 0 - err_str: “”
If denied: - result = approval = false // CBOR boolean - err_code: 0 // No error, deny is valid user choice - err_str: “” // No error, deny is valid user choice
where:
- approval: Whether the user approved or denied the execution request
Note, relayed messages are encrypted and authenticated on the timestamp and request/response id, so there’s no need for further complications.
Fields
taskid: u64Task id returned by ExecutionUploadStartResponse