pub struct ExecutionUploadChunkRequest {
pub taskid: u64,
pub chunk: Vec<u8>,
}Expand description
ExecutionUploadChunkRequest appends a chunk of data to a pending upload. Chunks must be appended in order and must not overrun the declared size.
Fields
taskid: u64Task id to append to
chunk: Vec<u8>Data chunk to append (reasonably capped)