pub struct FirmwareUpdateInitRequest {
pub access: Vec<u8>,
}Expand description
FirmwareUpdateInitRequest initiates a previously prepared firmware update procedure by providing the authenticated and encrypted firmware key.
Note, if the initiation is rejected, the entire update process is torn down.
Fields
access: Vec<u8>Seal[Cloud->temp-key][“firmware-v1”][version, sha256]