pub struct FirmwareUpdatePrepResponse {
pub auth: Vec<u8>,
}Expand description
FirmwareUpdatePrepResponse confirms whether a new firmware update process was started, or if the request was rejected and why.
If it was accepted, a new ephemeral encryption identity is generated by the Ark to receive the firmware access key to; and sent along with the firmware infos.
Fields
auth: Vec<u8>Seal[Ark->Cloud][“firmware-v1”][version, sha256]