pub struct FirmwareUpdateUploadResponse {}Expand description
FirmwareUpdateUploadResponse is the response whether the requested chunk was accepted or rejected.
Note, if the upload is rejected, the entire update process is torn down.