pub struct HostToArk {
pub id: Option<u64>,
pub content: Option<Content>,
}Expand description
HostToArk represents a message sent from the host to the Ark via the USB connection. It embeds all possible message types to keep the protocol simple.
Fields
id: Option<u64>Enveloping fields, reserved range 0x001-0x0ff
content: Option<Content>Implementations