pub struct PairingAuthResponse {
pub auth: Vec<u8>,
pub fprint: Vec<u8>,
}Expand description
PairingAuthResponse responds whether the device is in a state compatible with pairing (i.e. reset) and if so, it signs an authorization for the server to open a new rendezvous point; containing the xHPKE public key to use for encrypting messages to this Ark after pairing.
Fields
auth: Vec<u8>Seal[Ark->Cloud][“pairing-v1”]null
fprint: Vec<u8>Fingerprint of the pair-key to transmit to the app out-of-protocol