pub struct RelayAppToArkResponse {
pub id: u64,
pub res: Vec<u8>,
}Expand description
RelayAppToArkResponse is an opaque response from the companion app to an opaque Ark request. The ark will respond with the deferred response to the original request.
Fields
id: u64Application layer request ID from the ark being responding to
res: Vec<u8>Seal[App->Ark][“relaying-v1:response”][id]([result, [err_code, err_str]])