pub struct RelayArkToAppRequest {
pub id: u64,
pub req: Vec<u8>,
}Expand description
RelayArkToAppRequest is an opaque request from the Ark to the companion app, which will generally be sent as an interim response to some other request, requiring authorization from the app side.
Fields
id: u64Application layer request ID from the ark
req: Vec<u8>Seal[Ark->App][“relaying-v1:request”][id]([method, [params…]])