pub struct RelayJoinResponse {
pub auth: Vec<u8>,
}Expand description
RelayJoinResponse responds whether the device is in a state compatible with relaying (i.e. paired) and if so, it signs an authorization for the server to join the rendezvous point.
Fields
auth: Vec<u8>Seal[Ark->Cloud][“relaying-v1”]null