SlotStatus

Struct SlotStatus 

pub struct SlotStatus {
    pub kind: i32,
    pub name: String,
    pub desc: String,
    pub origin: i32,
    pub filled: bool,
    pub damaged: String,
    pub deps: Vec<i32>,
    pub meta: Option<Meta>,
}
SlotStatus describes the current state of a single slot slot on the device.

Fields

kind: i32

Slot type

name: String

Human-readable slot name

desc: String

Detailed description of this slot

origin: i32

Nature of the data (personal, reference, generated)

filled: bool

Whether data is present on the device

damaged: String

Non-empty if data files exist but metadata is missing/corrupt

deps: Vec<i32>

Slots that must be filled before this one is actionable

meta: Option<Meta>

Slot-type-specific metadata, set when the device has information about this slot (either filled or dependencies provide enough context).

Implementations

Source

impl SlotStatus

pub fn kind(&self) -> SlotKind

Returns the enum value of kind, or the default if the field is set to an invalid enum value.

pub fn set_kind(&mut self, value: SlotKind)

Sets kind to the provided enum value.

pub fn origin(&self) -> SlotOrigin

Returns the enum value of origin, or the default if the field is set to an invalid enum value.

pub fn set_origin(&mut self, value: SlotOrigin)

Sets origin to the provided enum value.

pub fn deps( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SlotKind>>

Returns an iterator which yields the valid enum values contained in deps.

pub fn push_deps(&mut self, value: SlotKind)

Appends the provided enum value to deps.