pub struct SlotUploadChunkRequest {
pub session: u64,
pub chunk: Vec<u8>,
}Expand description
SlotUploadChunkRequest contains a new chunk of data to append to a pending upload session.
Fields
session: u64Session id into which to append a new chunk
chunk: Vec<u8>Data chunk to append (reasonably capped)