pub struct SlotUploadPeekRequest {
pub name: String,
pub size: u64,
pub chunk: Vec<u8>,
pub kinds: Vec<i32>,
}Expand description
SlotUploadPeekRequest can be used to send an ephemeral file chunk to the Ark and ask it to attempt to identify it for the caller. Its purpose is to allow quickly filtering out potentially huge slots without uploading them first (e.g. q 30GB compressed whole genome sequencing).
Fields
name: StringSlot file name to guess the contents of
size: u64Slot file size to guess the contents of
chunk: Vec<u8>Slot first chunk to guess the contents of
kinds: Vec<i32>Possible slot items to interpret as (empty == any)
Implementations