pub struct SlotUploadPeekResponse {
pub kind: i32,
pub conf: i32,
pub summary: String,
pub details: String,
pub reject: String,
}Expand description
SlotUploadPeekResponse contains the data identification based on the small chunk shared in the request.
Fields
kind: i32Identified slot type to use during upload
conf: i32Identification confidence level
summary: StringShort summary of the identified slot type
details: StringDetailed description of the identified slot type
reject: StringReason why the slot is rejected
Implementations
Sourceimpl SlotUploadPeekResponse
impl SlotUploadPeekResponse
Sourcepub fn kind(&self) -> SlotKind
pub fn kind(&self) -> SlotKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn conf(&self) -> SlotConfidence
pub fn conf(&self) -> SlotConfidence
Returns the enum value of conf, or the default if the field is set to an invalid enum value.
Sourcepub fn set_conf(&mut self, value: SlotConfidence)
pub fn set_conf(&mut self, value: SlotConfidence)
Sets conf to the provided enum value.