#[repr(i32)]pub enum ReservedErrors {
Unspecified = 0,
Unanswered = 1,
Unknown = 2,
Unsupported = 3,
Unavailable = 4,
}Expand description
ReservedErrors names the assigned protocol-wide errors in the reserved range 0x00 to 0xff (inclusive). No code in this range may be assigned a request specific meaning. Assigned codes must not be repurposed.
Variants
Unspecified = 0
A failure without a standardized reason. Zero does not indicate success; the presence of an Error in the response indicates failure.
Unanswered = 1
The request’s responder was released without providing an application reply.
Unknown = 2
The peer does not know this request. Emitted by the protocol layer itself when a request’s content is not in its schema.
Unsupported = 3
The peer knows this request but never serves it in this build or role, firmware updates on an emulator or develop envelopes on production.
The peer serves this request but not in its current state, before cloud sync or pairing. It may once the state changes.
Implementations
Sourceimpl ReservedErrors
impl ReservedErrors
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.