pub struct SlotStatus {
pub kind: i32,
pub name: String,
pub desc: String,
pub origin: i32,
pub filled: bool,
pub damaged: String,
pub deps: Vec<i32>,
pub meta: Option<Meta>,
}Expand description
SlotStatus describes the current state of a single slot slot on the device.
Fields
kind: i32Slot type
name: StringHuman-readable slot name
desc: StringDetailed description of this slot
origin: i32Nature of the data (personal, reference, generated)
filled: boolWhether data is present on the device
damaged: StringNon-empty if data files exist but metadata is missing/corrupt
deps: Vec<i32>Slots that must be filled before this one is actionable
meta: Option<Meta>Slot-type-specific metadata, set when the device has information about this slot (either filled or dependencies provide enough context).
Implementations
Sourceimpl SlotStatus
impl SlotStatus
Sourcepub fn kind(&self) -> SlotKind
pub fn kind(&self) -> SlotKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn origin(&self) -> SlotOrigin
pub fn origin(&self) -> SlotOrigin
Returns the enum value of origin, or the default if the field is set to an invalid enum value.
Sourcepub fn set_origin(&mut self, value: SlotOrigin)
pub fn set_origin(&mut self, value: SlotOrigin)
Sets origin to the provided enum value.