pub struct UnlockRequest {}Expand description
UnlockRequest requests the device to start the unlock procedure. This request is async, potentially returning a response only after confirming with the app.
It will trigger sending a RelayArkToAppRequest with the request content:
- method: “unlock”
- params: []
The request expects a RelayAppToArkResponse with the response content:
If approved: - result = key: [u8; 32] // Shared secret from the pairing protocol - err_code: 0 - err_str: “”
If denied: - result = key = [0u8; 32] // All zeroes (signals a denial) - err_code: 0 // No error, deny is valid user choice - err_str: “” // No error, deny is valid user choice
where:
- key: Symmetric key for accessing the storage partition
Note, relayed messages are encrypted and authenticated on the timestamp and request/response id, so there’s no need for further complications.